# coding=utf-8
from __future__ import unicode_literals

from collections import OrderedDict

from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_female = OrderedDict((
        ('{{first_name_female}} {{last_name}}', 0.9),
        ('{{prefix_female}} {{first_name_female}} {{last_name}}', 0.1),
    ))

    formats_male = OrderedDict((
        ('{{first_name_male}} {{last_name}}', 0.9),
        ('{{prefix_male}} {{first_name_male}} {{last_name}}', 0.1),
    ))

    formats = formats_female.copy()
    formats.update(formats_male)

    # Source: uk.wikipedia.org/wiki/Українські_імена
    first_names_male = (
        'Аарон', 'Августин', 'Аврелій', 'Адам', 'Азар', 'Алевтин', 'Альберт',
        'Амвросій', 'Андрій', 'Антон', 'Аркадій', 'Арсен', 'Артем', 'Орхип',
        'Богдан', 'Богодар', 'Богуслав', 'Болеслав', 'Борис', 'Борислав',
        'Вадим', 'Валентин', 'Валерій', 'Варфоломій', 'Василь', 'Венедикт',
        'Веніямин', 'Віктор', 'Віталій', 'Владислав', 'Володимир',
        'Вʼячеслав', 'Гаврило', 'Геннадій', 'Георгій', 'Герман ', 'Гордій',
        'Григорій', 'Гліб', 'Данило', 'Давид', 'Дан', 'Демид', 'Демʼян',
        'Дмитро', 'Захар', 'Зиновій', 'Зорян', 'Іван', 'Ігнат', 'Ігор', 'Ілля',
        'Едуард', 'Євген', 'Єлисей', 'Єфрем', 'Йосип', 'Климент', 'Костянтин',
        'Левко', 'Лесь', 'Леон', 'Леонід', 'Леонтій', 'Леопольд', 'Лукʼян',
        'Кирило', 'Макар', 'Максим', 'Марко', 'Мартин', 'Микита', 'Миколай',
        'Мирон', 'Мирослав', 'Михайло', 'Назар', 'Нестор', 'Олег', 'Олекса',
        'Олександр', 'Олесь', 'Омелян', 'Онисим', 'Опанас', 'Орест', 'Остап',
        'Охрім', 'Петро', 'Павло', 'Панас', 'Пантелеймон', 'Пармен', 'Пилип',
        'Прохір', 'Роман', 'Ростислав', 'Руслан', 'Святослав', 'Семен',
        'Сергій', 'Симон', 'Соломон', 'Спас', 'Станіслав', 'Степан', 'Стефан',
        'Тарас', 'Теодор', 'Тимофій', 'Трохим', 'Устим', 'Федір', 'Феофан',
        'Франц', 'Хома', 'Юстим', 'Юхим', 'Яків', 'Ярема', 'Ярослав'
    )

    first_names_female = (
        'Ада', 'Аліна', 'Алла', 'Альбіна', 'Амалія', 'Анастасія', 'Аніта',
        'Анжела', 'Ганна', 'Богуслава', 'Богданна', 'Валентина', 'Варвара',
        'Василина', 'Вікторія', 'Віолетта', 'Віра', 'Володимира', 'Галина',
        'Данна', 'Дарина', 'Едита', 'Єва', 'Єлисавета', 'Емілія', 'Еріка',
        'Ірина', 'Ірена', 'Златослава', 'Камілла', 'Клавдія', 'Лариса', 'Ліза',
        'Лілія', 'Людмила', 'Любов', 'Марія', 'Марина', 'Марта', 'Марʼяна',
        'Маруся', 'Михайлина', 'Мілена', 'Надія', 'Наталія', 'Пріска',
        'Розалія', 'Святослава', 'Сніжана', 'Соломія', 'Софія', 'Одарка',
        'Оксана', 'Оксенія', 'Олена', 'Ольга', 'Орина', 'Орися', 'Роксолана',
        'Світлана', 'Тереза', 'Тетяна', 'Юстина', 'Христина', 'Ярина',
        'Ярослава'
    )

    first_names = first_names_male + first_names_female

    # Source: uk.wikipedia.org/wiki/Категорія:Українські_прізвища
    last_names = (
        'Абрагамовський', 'Абраменко', 'Абрамчук', 'Авдєєнко', 'Аверченко',
        'Авраменко', 'Аврамчук', 'Адаменко', 'Адамчук', 'Ажажа', 'Акименко',
        'Акуленко', 'Александренко', 'Алексеєнко', 'Алексійчук', 'Алексюк',
        'Андрейко', 'Андрієвич', 'Андрієнко', 'Андріїшин', 'Андрійович',
        'Андрійчук', 'Андрощук', 'Андрусенко', 'Аронець', 'Арсенич',
        'Артеменко', 'Артим', 'Артимишин', 'Артимович', 'Артюх', 'Артюшенко',
        'Архимович', 'Архипенко', 'Асаула', 'Атаманчук', 'Атаманюк',
        'Атрощенко', 'Бабʼюк', 'Бабʼяк', 'Бабак', 'Бабариченко', 'Бабенко',
        'Бабич', 'Бабиченко', 'Бабій', 'Бабійчук', 'Бабко', 'Базавлученко',
        'Базилевич', 'Базилевський', 'Байда', 'Байдак', 'Байрак', 'Баклан',
        'Бакуменко', 'Балабан', 'Бандера', 'Бандура', 'Бандурка', 'Барабаш',
        'Баран', 'Баранець', 'Бараник', 'Баранник', 'Батіг', 'Батуринець',
        'Батюк', 'Башполченко', 'Баштан', 'Бгиденко', 'Бебешко', 'Бевз',
        'Бевзенко', 'Безбородьки', 'Безбородько', 'Бездітко', 'Вакарчук',
        'Вакуленко', 'Валенко', 'Ванченко', 'Василашко', 'Василевич',
        'Василенко', 'Василечко', 'Ватаманюк', 'Вахній', 'Ващенко',
        'Ващенко-Захарченко', 'Ващук', 'Вдовенко', 'Вдовиченко', 'Величко',
        'Венгринович', 'Вергун', 'Верес', 'Верменич', 'Вернигора', 'Вернидуб',
        'Вертипорох', 'Верховинець', 'Верхола', 'Височан', 'Вишиваний',
        'Вишняк', 'Вівчаренко', 'Вітер', 'Вітрук', 'Власенко', 'Власюк',
        'Влох', 'Воблий', 'Вовк', 'Габелко', 'Гавриленко', 'Гаврилець',
        'Гаврилишин', 'Гаврилів', 'Гаврилюк', 'Гавриш', 'Гавришкевич',
        'Гаврюшенко', 'Гаєвський', 'Гайворонський', 'Гайда', 'Гайдабура',
        'Гайдай', 'Гайдамака', 'Гайденко', 'Гоголь', 'Гоголь-Яновський',
        'Годунок', 'Голик', 'Голобородько', 'Гресь', 'Гречаник', 'Гречко',
        'Гриценко', 'Гузенко', 'Гузій', 'Гузь', 'Гук', 'Гунько', 'Гупало',
        'Гуцуляк', 'Ґалаґан', 'Ґереґа', 'Ґерета', 'Ґерус', 'Ґжицький', 'Ґоляш',
        'Давиденко', 'Давимука', 'Даниленко', 'Данилюк', 'Данильчук',
        'Данченко', 'Данчук', 'Данькевич', 'Даньків', 'Данько', 'Дараган',
        'Дахно', 'Даценко', 'Дацюк', 'Дашенко', 'Дашкевич', 'Девдюк',
        'Дейнека', 'Дейнеко', 'Дейсун', 'Демʼяненко', 'Демʼянчук', 'Демʼянюк',
        'Демиденко', 'Дергач', 'Деревʼянко', 'Дерегус', 'Деркач', 'Деряжний',
        'Джунь', 'Джус', 'Дробʼязко', 'Дробаха', 'Дрозд', 'Дрозденко',
        'Дубас', 'Дубенко', 'Дубина', 'Дзиндра', 'Дзюба', 'Доценко', 'Дуплій',
        'Дурдинець', 'Дутка', 'Ейбоженко', 'Євдокименко', 'Євтушенко',
        'Євтушок', 'Ємельяненко', 'Ємець', 'Єременко', 'Єресько', 'Єрмоленко',
        'Єрошенко', 'Єрченко', 'Єрьоменко', 'Єсипенко', 'Єфименко', 'Єщенко',
        'Жадан', 'Жайворон', 'Жаліло', 'Жарко', 'Жук', 'Журавель', 'Журба',
        'Жученко', 'Забара', 'Забарний', 'Забашта', 'Забіла', 'Заєць', 'Заїка',
        'Зайченко', 'Закусило', 'Запорожець', 'Заруба', 'Зарудний', 'Засенко',
        'Засуха', 'Засядько', 'Затовканюк', 'Затула', 'Захаренко',
        'Захарченко', 'Зінкевич', 'Зінченко', 'Зінчук', 'Зубко', 'Іваненко',
        'Іваничук', 'Іванченко', 'Івасюк', 'Іващенко', 'Ільєнко', 'Ільченко',
        'Ірванець', 'Ісаєвич', 'Ісаєнко', 'Іщак', 'Іщенко', 'Їжак', 'Їжакевич',
        'Кабалюк', 'Кабаненко', 'Каденюк', 'Калениченко', 'Кальченко',
        'Канівець', 'Карась', 'Кармалюк', 'Карпа', 'Карпенко', 'Кащенко',
        'Кибкало', 'Килимник', 'Кириленко', 'Коваленко', 'Ковалюк', 'Ковпак',
        'Козак', 'Козаченко', 'Колесниченко', 'Колісниченко', 'Колодуб',
        'Комар', 'Конопленко', 'Конопля', 'Копитко', 'Корбут', 'Корж',
        'Короленко', 'Корпанюк', 'Корсун', 'Лаба', 'Лавренко', 'Лагода',
        'Лазаренко', 'Левченко', 'Лемешко', 'Лесик', 'Лисенко', 'Литвин',
        'Литвиненко', 'Лубенець', 'Лукаш', 'Лупій', 'Луценко', 'Ляшко',
        'Мазепа', 'Мазур', 'Макаренко', 'Макогон', 'Малик', 'Малишко',
        'Мамчур', 'Масляк', 'Масоха', 'Матвієнко', 'Матяш', 'Медведенко',
        'Микитюк', 'Михайличенко', 'Михайлюк', 'Михалюк', 'Мірошниченко',
        'Міщенко', 'Москаль', 'Назаренко', 'Наливайко', 'Негода', 'Непорожній',
        'Нестайко', 'Нестеренко', 'Ніколюк', 'Носаченко', 'Носенко',
        'Оберемко', 'Овсієнко', 'Овчаренко', 'Олійник', 'Оліфіренко',
        'Онищенко', 'Оніщук', 'Онуфрієнко', 'Опанасенко', 'Орлик', 'Оробець',
        'Остапчук', 'Охримович', 'Охріменко', 'Пʼятаченко', 'Павленко',
        'Павлик', 'Павличенко', 'Палій', 'Панчук', 'Парасюк', 'Пелех',
        'Перебийніс', 'Перепелиця', 'Петлюра', 'Петренко', 'Петрик',
        'Пилипенко', 'Піддубний', 'Полтавець', 'Приймак', 'Примаченко',
        'Притула', 'Приходько', 'Прокопович', 'Проценко', 'Пустовіт', 'Пушкар',
        'Радченко', 'Рак', 'Ребрик', 'Рева', 'Редько', 'Романенко', 'Романець',
        'Романчук', 'Рубан', 'Рубець', 'Рудик', 'Рудько', 'Рябець', 'Рябовіл',
        'Рябошапка', 'Рябченко', 'Савенко', 'Сагаль', 'Саєнко', 'Салій',
        'Самойленко', 'Сацюк', 'Саченко', 'Свириденко', 'Свистун',
        'Семенченко', 'Симоненко', 'Сиротенко', 'Сич', 'Сімашкевич', 'Сірко',
        'Сіробаба', 'Сірченко', 'Скиба', 'Скирда', 'Скопенко', 'Скорик',
        'Скоробогатько', 'Смик', 'Слюсар', 'Сомко', 'Стельмах', 'Стець',
        'Стус', 'Супруненко', 'Талан', 'Таран', 'Тарасенко', 'Твердохліб',
        'Теличенко', 'Теліженко', 'Терещенко', 'Терещук', 'Тесленко', 'Тесля',
        'Тимченко', 'Тимчук', 'Титаренко', 'Тихий', 'Тичина', 'Ткач',
        'Ткаченко', 'Товстоліс', 'Товстуха', 'Токар', 'Тригуб', 'Туркало',
        'Тягнибок', 'Удовенко', 'Удовиченко', 'Уманець', 'Усик', 'Устенко',
        'Фаренюк', 'Фартушняк', 'Фастенко', 'Фесенко', 'Філіпенко', 'Фоменко',
        'Франко', 'Франчук', 'Фурс', 'Харченко', 'Хмара', 'Хоменко', 'Хомик',
        'Хорішко', 'Христенко', 'Христич', 'Худобʼяк', 'Худяк', 'Царенко',
        'Цибуленко', 'Цимбал', 'Цимбалюк', 'Цісик', 'Цушко', 'Цюпа', 'Цюцюра',
        'Чабан', 'Чайка', 'Чаленко', 'Чалий', 'Чарниш', 'Чекалюк',
        'Червоненко', 'Чередник', 'Черінько', 'Черненко', 'Чміль', 'Чорновіл',
        'Чубай', 'Чуйко', 'Чумак', 'Чумаченко', 'Чуприна', 'Шаблій', 'Шамрай',
        'Шаповал', 'Шахрай', 'Швайка', 'Швачка', 'Швачко', 'Шведченко',
        'Шеремета', 'Шевченко', 'Шелест', 'Шеремет', 'Шило', 'Шинкаренко',
        'Шиян', 'Шморгун', 'Шовкопляс', 'Штепа', 'Штокало', 'Шутько',
        'Шухевич', 'Щербак', 'Щербань', 'Щириця', 'Щорс', 'Юрченко', 'Юрчишин',
        'Юрчук', 'Юхименко', 'Ющенко', 'Якименко', 'Якимчук', 'Яковенко',
        'Ярема', 'Яременко', 'Яремків', 'Яремко', 'Яремчук', 'Ярош', 'Яценко',
        'Яценюк', 'Ященко', 'Ящук',
    )

    prefixes_male = ('пан',)
    prefixes_female = ('пані',)



# coding: utf-8

from __future__ import unicode_literals
from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):

    def day_of_week(self):
        day = self.date('%w')
        DAY_NAMES = {
            "0": "Senin",
            "1": "Selasa",
            "2": "Rabu",
            "3": "Kamis",
            "4": "Jumat",
            "5": "Sabtu",
            "6": "Minggu",
        }

        return DAY_NAMES[day]

    def month_name(self):
        month = self.month()
        MONTH_NAMES = {
            "01": "Januari",
            "02": "Februari",
            "03": "Maret",
            "04": "April",
            "05": "Mei",
            "06": "Juni",
            "07": "Juli",
            "08": "Agustus",
            "09": "September",
            "10": "Oktober",
            "11": "November",
            "12": "Desember",
        }

        return MONTH_NAMES[month]



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as InternetProvider


class Provider(InternetProvider):

    user_name_formats = (
        '{{last_name}}.{{first_name_female}}',
        '{{last_name}}.{{first_name_male}}',
        '{{first_name_female}}.{{last_name}}',
        '{{first_name_male}}.{{last_name}}',
        '{{first_name}}##',
    )

    email_formats = ('{{user_name}}@{{free_email_domain}}', )

    free_email_domains = (
        'gmail.com', 'siol.net', 'email.si', 'volja.net',
    )

    uri_pages = (
        'index', 'domov', 'iskanje', 'main', 'novica',
        'homepage', 'kategorija', 'registracija', 'login',
        'faq', 'o-nas', 'pogoji',
        'zasebnost', 'avtor'
    )
    uri_paths = (
        'app', 'main', 'wp-content', 'iskanje', 'kategorija', 'novica',
        'kategorije', 'novice', 'blog', 'komentarji', 'seznam')
    uri_extensions = (
        '.html', '.html', '.html', '.htm', '.htm', '.php',
        '.php', '.jsp', '.asp'
    )

    tlds = ('si', 'com',)



from __future__ import unicode_literals
import re
from ..en import Provider as AddressProvider


class Provider(AddressProvider):

    postal_code_letters = (
        'A', 'B', 'C', 'E', 'G', 'H', 'J', 'K', 'L', 'M', 'N', 'P', 'R', 'S',
        'T', 'V', 'X', 'Y',
    )

    city_prefixes = ('North', 'East', 'West', 'South', 'New', 'Lake', 'Port')

    city_suffixes = (
        'town',
        'ton',
        'land',
        'ville',
        'berg',
        'burgh',
        'borough',
        'bury',
        'view',
        'port',
        'mouth',
        'stad',
        'furt',
        'chester',
        'mouth',
        'fort',
        'haven',
        'side',
        'shire')

    building_number_formats = ('#####', '####', '###')

    street_suffixes = (
        'Alley',
        'Avenue',
        'Branch',
        'Bridge',
        'Brook',
        'Brooks',
        'Burg',
        'Burgs',
        'Bypass',
        'Camp',
        'Canyon',
        'Cape',
        'Causeway',
        'Center',
        'Centers',
        'Circle',
        'Circles',
        'Cliff',
        'Cliffs',
        'Club',
        'Common',
        'Corner',
        'Corners',
        'Course',
        'Court',
        'Courts',
        'Cove',
        'Coves',
        'Creek',
        'Crescent',
        'Crest',
        'Crossing',
        'Crossroad',
        'Curve',
        'Dale',
        'Dam',
        'Divide',
        'Drive',
        'Drive',
        'Drives',
        'Estate',
        'Estates',
        'Expressway',
        'Extension',
        'Extensions',
        'Fall',
        'Falls',
        'Ferry',
        'Field',
        'Fields',
        'Flat',
        'Flats',
        'Ford',
        'Fords',
        'Forest',
        'Forge',
        'Forges',
        'Fork',
        'Forks',
        'Fort',
        'Freeway',
        'Garden',
        'Gardens',
        'Gateway',
        'Glen',
        'Glens',
        'Green',
        'Greens',
        'Grove',
        'Groves',
        'Harbor',
        'Harbors',
        'Haven',
        'Heights',
        'Highway',
        'Hill',
        'Hills',
        'Hollow',
        'Inlet',
        'Inlet',
        'Island',
        'Island',
        'Islands',
        'Islands',
        'Isle',
        'Isle',
        'Junction',
        'Junctions',
        'Key',
        'Keys',
        'Knoll',
        'Knolls',
        'Lake',
        'Lakes',
        'Land',
        'Landing',
        'Lane',
        'Light',
        'Lights',
        'Loaf',
        'Lock',
        'Locks',
        'Locks',
        'Lodge',
        'Lodge',
        'Loop',
        'Mall',
        'Manor',
        'Manors',
        'Meadow',
        'Meadows',
        'Mews',
        'Mill',
        'Mills',
        'Mission',
        'Mission',
        'Motorway',
        'Mount',
        'Mountain',
        'Mountain',
        'Mountains',
        'Mountains',
        'Neck',
        'Orchard',
        'Oval',
        'Overpass',
        'Park',
        'Parks',
        'Parkway',
        'Parkways',
        'Pass',
        'Passage',
        'Path',
        'Pike',
        'Pine',
        'Pines',
        'Place',
        'Plain',
        'Plains',
        'Plains',
        'Plaza',
        'Plaza',
        'Point',
        'Points',
        'Port',
        'Port',
        'Ports',
        'Ports',
        'Prairie',
        'Prairie',
        'Radial',
        'Ramp',
        'Ranch',
        'Rapid',
        'Rapids',
        'Rest',
        'Ridge',
        'Ridges',
        'River',
        'Road',
        'Road',
        'Roads',
        'Roads',
        'Route',
        'Row',
        'Rue',
        'Run',
        'Shoal',
        'Shoals',
        'Shore',
        'Shores',
        'Skyway',
        'Spring',
        'Springs',
        'Springs',
        'Spur',
        'Spurs',
        'Square',
        'Square',
        'Squares',
        'Squares',
        'Station',
        'Station',
        'Stravenue',
        'Stravenue',
        'Stream',
        'Stream',
        'Street',
        'Street',
        'Streets',
        'Summit',
        'Summit',
        'Terrace',
        'Throughway',
        'Trace',
        'Track',
        'Trafficway',
        'Trail',
        'Trail',
        'Tunnel',
        'Tunnel',
        'Turnpike',
        'Turnpike',
        'Underpass',
        'Union',
        'Unions',
        'Valley',
        'Valleys',
        'Via',
        'Viaduct',
        'View',
        'Views',
        'Village',
        'Village',
        'Villages',
        'Ville',
        'Vista',
        'Vista',
        'Walk',
        'Walks',
        'Wall',
        'Way',
        'Ways',
        'Well',
        'Wells')

    postal_code_formats = ('?%? %?%', '?%?%?%')

    provinces = (
        'Alberta', 'British Columbia', 'Manitoba', 'New Brunswick',
        'Newfoundland and Labrador', 'Northwest Territories',
        'New Brunswick', 'Nova Scotia', 'Nunavut', 'Ontario',
        'Prince Edward Island', 'Quebec', 'Saskatchewan', 'Yukon Territory')

    provinces_abbr = (
        'AB', 'BC', 'MB', 'NB', 'NL', 'NT', 'NS',
        'NV', 'ON', 'PE', 'QC', 'SK', 'YT')

    city_formats = (
        '{{city_prefix}} {{first_name}}{{city_suffix}}',
        '{{city_prefix}} {{first_name}}',
        '{{first_name}}{{city_suffix}}',
        '{{last_name}}{{city_suffix}}',
    )
    street_name_formats = (
        '{{first_name}} {{street_suffix}}',
        '{{last_name}} {{street_suffix}}'
    )
    street_address_formats = (
        '{{building_number}} {{street_name}}',
        '{{building_number}} {{street_name}} {{secondary_address}}',
    )
    address_formats = (
        "{{street_address}}\n{{city}}, {{province_abbr}} {{postalcode}}",
    )
    secondary_address_formats = ('Apt. ###', 'Suite ###')

    def province(self):
        """
        """
        return self.random_element(self.provinces)

    def province_abbr(self):
        return self.random_element(self.provinces_abbr)

    def city_prefix(self):
        return self.random_element(self.city_prefixes)

    def secondary_address(self):
        return self.numerify(
            self.random_element(
                self.secondary_address_formats))

    def postal_code_letter(self):
        """
        Returns a random letter from the list of allowable
        letters in a canadian postal code
        """
        return self.random_element(self.postal_code_letters)

    def postalcode(self):
        """
        Replaces all question mark ('?') occurrences with a random letter
        from postal_code_formats then passes result to
        numerify to insert numbers
        """
        temp = re.sub(r'\?',
                      lambda x: self.postal_code_letter(),
                      self.random_element(self.postal_code_formats))
        return self.numerify(temp)



# coding=utf-8

from __future__ import print_function
from __future__ import unicode_literals

import os
import pprint
import sys


if sys.version < '3':
    text_type = unicode
    binary_type = str
else:
    text_type = str
    binary_type = bytes


DOCS_ROOT = os.path.abspath(os.path.join('..', 'docs'))


def write(fh, s):
    return fh.write(s.encode('utf-8'))


def write_provider(fh, doc, provider, formatters, excludes=None):

    if excludes is None:
        excludes = []

    write(fh, '\n')
    title = "``{0}``".format(doc.get_provider_name(provider))
    write(fh, '%s\n' % title)
    write(fh, "-" * len(title))
    write(fh, '\n\n::\n')

    for signature, example in formatters.items():
        if signature in excludes:
            continue
        try:
            # `pprint` can't format sets of heterogenous types.
            if not isinstance(example, set):
                example = pprint.pformat(example, indent=4)
            lines = text_type(example).expandtabs().splitlines()
        except UnicodeEncodeError:
            msg = 'error on "{0}" with value "{1}"'.format(signature, example)
            raise Exception(msg)
        write(fh, '\n')
        write(fh, "\t{fake}\n{example}\n".format(
            fake=signature,
            example='\n'.join(['\t# ' + line for line in lines]),
        ))


def write_docs(*args, **kwargs):
    from faker import Faker, documentor
    from faker.config import DEFAULT_LOCALE, AVAILABLE_LOCALES

    fake = Faker(locale=DEFAULT_LOCALE)

    from faker.providers import BaseProvider
    base_provider_formatters = [f for f in dir(BaseProvider)]

    doc = documentor.Documentor(fake)

    formatters = doc.get_formatters(with_args=True, with_defaults=True)

    for provider, fakers in formatters:
        provider_name = doc.get_provider_name(provider)
        fname = os.path.join(DOCS_ROOT, 'providers', '%s.rst' % provider_name)
        with open(fname, 'wb') as fh:
            write_provider(fh, doc, provider, fakers)

    with open(os.path.join(DOCS_ROOT, 'providers.rst'), 'wb') as fh:
        write(fh, 'Providers\n')
        write(fh, '=========\n')
        write(fh, '.. toctree::\n')
        write(fh, '   :maxdepth: 2\n\n')
        [write(fh, '   providers/%s\n' % doc.get_provider_name(provider))
         for provider, fakers in formatters]

    AVAILABLE_LOCALES = sorted(AVAILABLE_LOCALES)
    for lang in AVAILABLE_LOCALES:
        fname = os.path.join(DOCS_ROOT, 'locales', '%s.rst' % lang)
        with open(fname, 'wb') as fh:
            write(fh, '\n')
            title = 'Language {0}\n'.format(lang)
            write(fh, title)
            write(fh, '=' * len(title))
            write(fh, '\n')
            fake = Faker(locale=lang)
            d = documentor.Documentor(fake)

            for p, fs in d.get_formatters(with_args=True, with_defaults=True,
                                          locale=lang,
                                          excludes=base_provider_formatters):
                write_provider(fh, d, p, fs)

    with open(os.path.join(DOCS_ROOT, 'locales.rst'), 'wb') as fh:
        write(fh, 'Locales\n')
        write(fh, '=======\n')
        write(fh, '.. toctree::\n')
        write(fh, '   :maxdepth: 2\n\n')
        [write(fh, '   locales/%s\n' % lang) for lang in AVAILABLE_LOCALES]


# wrappers for sphinx
def _main(app, *args, **kwargs):
    return write_docs(*args, **kwargs)


def setup(app):
    app.connect(str('builder-inited'), _main)


if __name__ == "__main__":
    write_docs(*sys.argv[1:])



# coding=utf-8

from __future__ import unicode_literals
from .. import BaseProvider


class Provider(BaseProvider):

    def ean(self, length=13):
        code = [self.random_digit() for _ in range(length - 1)]

        if length not in (8, 13):
            raise AssertionError("length can only be 8 or 13")

        if length == 8:
            weights = [3, 1, 3, 1, 3, 1, 3]
        elif length == 13:
            weights = [1, 3, 1, 3, 1, 3, 1, 3, 1, 3, 1, 3]

        weighted_sum = sum([x * y for x, y in zip(code, weights)])
        check_digit = (10 - weighted_sum % 10) % 10
        code.append(check_digit)

        return ''.join(str(x) for x in code)

    def ean8(self):
        return self.ean(8)

    def ean13(self):
        return self.ean(13)



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as AddressProvider


class Provider(AddressProvider):

    city_formats = ('{{city_name}}', )

    street_name_formats = (
        '{{first_name}}-{{last_name}}-{{street_suffix_long}}',
        '{{last_name}}{{street_suffix_short}}',
    )
    street_address_formats = ('{{street_name}} {{building_number}}', )
    address_formats = ('{{street_address}}\n{{postcode}} {{city}}', )

    building_number_formats = ('###', '##', '#', '#/#', )

    street_suffixes_long = (
        'Gasse', 'Platz', 'Ring', 'Straße', 'Weg'
    )
    street_suffixes_short = (
        'gasse', 'platz', 'ring', 'straße', 'str.', 'weg'
    )

    # https://en.wikipedia.org/wiki/List_of_postal_codes_in_Austria
    postcode_formats = (
        '1###',
        '2###',
        '3###',
        '4###',
        '5###',
        '6###',
        '7###',
        '8###',
        '9###'
    )

    # https://en.wikipedia.org/wiki/List_of_cities_and_towns_in_Austria
    cities = (
        'Allentsteig', 'Altheim', 'Althofen', 'Amstetten', 'Ansfelden', 'Attnang-Puchheim',
        'Bad Aussee', 'Bad Hall', 'Bad Ischl', 'Bad Leonfelden', 'Bad Radkersburg',
        'Bad Sankt Leonhard im Lavanttal', 'Bad Vöslau', 'Baden', 'Bärnbach', 'Berndorf',
        'Bischofshofen', 'Bleiburg', 'Bludenz', 'Braunau am Inn', 'Bregenz',
        'Bruck an der Leitha', 'Bruck an der Mur', 'Deutsch-Wagram', 'Deutschlandsberg',
        'Dornbirn', 'Drosendorf-Zissersdorf 1', 'Dürnstein', 'Ebenfurth', 'Ebreichsdorf',
        'Eferding', 'Eggenburg', 'Eisenerz', 'Eisenstadt', 'Enns', 'Fehring', 'Feldbach',
        'Feldkirch', 'Feldkirchen', 'Ferlach', 'Fischamend', 'Frauenkirchen', 'Freistadt',
        'Friedberg', 'Friesach', 'Frohnleiten', 'Fürstenfeld', 'Gallneukirchen', 'Gänserndorf',
        'Geras', 'Gerasdorf bei Wien', 'Gföhl', 'Gleisdorf', 'Gloggnitz', 'Gmünd',
        'Gmünd in Kärnten', 'Gmunden', 'Graz', 'Grein', 'Grieskirchen', 'Groß-Enzersdorf',
        'Groß-Gerungs', 'Groß-Siegharts', 'Güssing', 'Haag', 'Hainburg an der Donau', 'Hainfeld',
        'Hall in Tirol', 'Hallein', 'Hardegg', 'Hartberg', 'Heidenreichstein', 'Herzogenburg',
        'Imst', 'Innsbruck', 'Jennersdorf', 'Judenburg', 'Kapfenberg', 'Kindberg', 'Klagenfurt',
        'Klosterneuburg', 'Knittelfeld', 'Köflach', 'Korneuburg', 'Krems an der Donau', 'Kufstein',
        'Laa an der Thaya', 'Laakirchen', 'Landeck', 'Langenlois', 'Leibnitz', 'Leoben', 'Lienz',
        'Liezen', 'Lilienfeld', 'Linz', 'Litschau', 'Maissau', 'Mank', 'Mannersdorf am Leithagebirge',
        'Marchegg', 'Marchtrenk', 'Mariazell', 'Mattersburg', 'Mattighofen', 'Mautern an der Donau',
        'Melk', 'Mistelbach an der Zaya', 'Mödling', 'Murau', 'Mureck', 'Mürzzuschlag', 'Neulengbach',
        'Neumarkt am Wallersee', 'Neunkirchen', 'Neusiedl am See', 'Oberndorf bei Salzburg',
        'Oberpullendorf', 'Oberwart', 'Oberwälz', 'Perg', 'Peuerbach', 'Pinkafeld', 'Pöchlarn',
        'Poysdorf', 'Pregarten', 'Pulkau', 'Purbach am Neusiedler See', 'Purkersdorf',
        'Raabs an der Thaya', 'Radenthein', 'Radstadt', 'Rattenberg', 'Retz', 'Ried im Innkreis',
        'Rohrbach in Oberösterreich', 'Rottenmann', 'Rust', 'Saalfelden am Steinernen Meer',
        'Salzburg', 'Sankt Andrä im Lavanttal', 'Sankt Johann im Pongau', 'Sankt Pölten',
        'Sankt Valentin', 'Sankt Veit an der Glan', 'Schärding', 'Scheibbs', 'Schladming',
        'Schrattenthal', 'Schrems', 'Schwanenstadt', 'Schwaz', 'Schwechat', 'Spittal an der Drau',
        'Stadtschlaining', 'Steyr', 'Steyregg', 'Stockerau', 'Straßburg', 'Ternitz', 'Traiskirchen',
        'Traismauer', 'Traun', 'Trieben', 'Trofaiach', 'Tulln an der Donau', 'Villach', 'Vils',
        'Vöcklabruck', 'Voitsberg', 'Völkermarkt', 'Waidhofen an der Thaya', 'Waidhofen an der Ybbs',
        'Weitra', 'Weiz', 'Wels', 'Wien', 'Wiener Neustadt', 'Wieselburg', 'Wilhelmsburg', 'Wolfsberg',
        'Wolkersdorf', 'Wörgl', 'Ybbs an der Donau', 'Zell am See', 'Zeltweg', 'Zistersdorf', 'Zwettl'
    )

    # https://en.wikipedia.org/wiki/States_of_Austria
    states = (
        'Wien', 'Steiermark', 'Burgenland', 'Tirol', 'Niederösterreich',
        'Oberösterreich', 'Salzburg', 'Kärnten', 'Vorarlberg'
    )

    countries = (
        'Afghanistan', 'Alandinseln', 'Albanien', 'Algerien',
        'Amerikanisch-Ozeanien', 'Amerikanisch-Samoa',
        'Amerikanische Jungferninseln', 'Andorra', 'Angola', 'Anguilla',
        'Antarktis', 'Antigua und Barbuda', 'Argentinien', 'Armenien', 'Aruba',
        'Aserbaidschan', 'Australien', 'Bahamas', 'Bahrain', 'Bangladesch',
        'Barbados', 'Belarus', 'Belgien', 'Belize', 'Benin', 'Bermuda',
        'Bhutan', 'Bolivien', 'Bosnien und Herzegowina', 'Botsuana',
        'Bouvetinsel', 'Brasilien', 'Britische Jungferninseln',
        'Britisches Territorium im Indischen Ozean', 'Brunei Darussalam',
        'Bulgarien', 'Burkina Faso', 'Burundi', 'Chile', 'China', 'Cookinseln',
        'Costa Rica', 'Côte d’Ivoire', 'Demokratische Republik Kongo',
        'Demokratische Volksrepublik Korea', 'Deutschland', 'Dominica',
        'Dominikanische Republik', 'Dschibuti', 'Dänemark', 'Ecuador',
        'El Salvador', 'Eritrea', 'Estland', 'Falklandinseln', 'Fidschi',
        'Finnland', 'Frankreich', 'Französisch-Guayana',
        'Französisch-Polynesien', 'Färöer', 'Gabun', 'Gambia', 'Georgien',
        'Ghana', 'Gibraltar', 'Grenada', 'Griechenland', 'Grönland',
        'Guadeloupe', 'Guam', 'Guatemala', 'Guernsey', 'Guinea',
        'Guinea-Bissau', 'Guyana', 'Haiti', 'Heard- und McDonald-Inseln',
        'Honduras', 'Indien', 'Indonesien', 'Irak', 'Iran', 'Irland', 'Island',
        'Isle of Man', 'Israel', 'Italien', 'Jamaika', 'Japan', 'Jemen',
        'Jersey', 'Jordanien', 'Kaimaninseln', 'Kambodscha', 'Kamerun',
        'Kanada', 'Kap Verde', 'Kasachstan', 'Katar', 'Kenia', 'Kirgisistan',
        'Kiribati', 'Kokosinseln', 'Kolumbien', 'Komoren', 'Kongo', 'Kroatien',
        'Kuba', 'Kuwait', 'Laos', 'Lesotho', 'Lettland', 'Libanon', 'Liberia',
        'Libyen', 'Liechtenstein', 'Litauen', 'Luxemburg', 'Madagaskar',
        'Malawi', 'Malaysia', 'Malediven', 'Mali', 'Malta', 'Marokko',
        'Marshallinseln', 'Martinique', 'Mauretanien', 'Mauritius', 'Mayotte',
        'Mazedonien', 'Mexiko', 'Mikronesien', 'Monaco', 'Mongolei',
        'Montenegro', 'Montserrat', 'Mosambik', 'Myanmar', 'Namibia', 'Nauru',
        'Nepal', 'Neukaledonien', 'Neuseeland', 'Nicaragua', 'Niederlande',
        'Niederländische Antillen', 'Niger', 'Nigeria', 'Niue', 'Norfolkinsel',
        'Norwegen', 'Nördliche Marianen', 'Oman', 'Osttimor', 'Pakistan',
        'Palau', 'Palästinensische Gebiete', 'Panama', 'Papua-Neuguinea',
        'Paraguay', 'Peru', 'Philippinen', 'Pitcairn', 'Polen', 'Portugal',
        'Puerto Rico', 'Republik Korea', 'Republik Moldau', 'Ruanda',
        'Rumänien', 'Russische Föderation', 'Réunion', 'Salomonen', 'Sambia',
        'Samoa', 'San Marino', 'Saudi-Arabien', 'Schweden', 'Schweiz',
        'Senegal', 'Serbien', 'Serbien und Montenegro', 'Seychellen',
        'Sierra Leone', 'Simbabwe', 'Singapur', 'Slowakei', 'Slowenien',
        'Somalia', 'Sonderverwaltungszone Hongkong',
        'Sonderverwaltungszone Macao', 'Spanien', 'Sri Lanka',
        'St. Barthélemy', 'St. Helena', 'St. Kitts und Nevis', 'St. Lucia',
        'St. Martin', 'St. Pierre und Miquelon',
        'St. Vincent und die Grenadinen', 'Sudan', 'Suriname',
        'Svalbard und Jan Mayen', 'Swasiland', 'Syrien',
        'São Tomé und Príncipe', 'Südafrika',
        'Südgeorgien und die Südlichen Sandwichinseln', 'Tadschikistan',
        'Taiwan', 'Tansania', 'Thailand', 'Togo', 'Tokelau', 'Tonga',
        'Trinidad und Tobago', 'Tschad', 'Tschechische Republik', 'Tunesien',
        'Turkmenistan', 'Turks- und Caicosinseln', 'Tuvalu', 'Türkei',
        'Uganda', 'Ukraine', 'Ungarn', 'Uruguay', 'Usbekistan', 'Vanuatu',
        'Vatikanstadt', 'Venezuela', 'Vereinigte Arabische Emirate',
        'Vereinigte Staaten', 'Vereinigtes Königreich', 'Vietnam',
        'Wallis und Futuna', 'Weihnachtsinsel', 'Westsahara',
        'Zentralafrikanische Republik', 'Zypern', 'Ägypten',
        'Äquatorialguinea', 'Äthiopien', 'Äußeres Ozeanien', 'Österreich',
    )

    def street_suffix_short(self):
        return self.random_element(self.street_suffixes_short)

    def street_suffix_long(self):
        return self.random_element(self.street_suffixes_long)

    def city_name(self):
        return self.random_element(self.cities)

    def state(self):
        return self.random_element(self.states)

    def latitude(self):
        return self.geo_coordinate(center=47.60707, radius=1)

    def longitude(self):
        return self.geo_coordinate(center=13.37208, radius=2)



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as InternetProvider


class Provider(InternetProvider):

    free_email_domains = (
        'telia.com', 'gmail.com', 'swipnet.se', 'googlemail.com', 'live.se',
        'spray.se', 'yahoo.de',
    )
    tlds = ('com', 'com', 'com', 'se', 'se', 'se', 'net', 'org')

    replacements = (
        ('å', 'a'), ('Å', 'A'),
        ('ä', 'a'), ('Ä', 'A'),
        ('ö', 'o'), ('Ö', 'O'),
    )



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider

# Source: SEFRI
# http://www.sbfi.admin.ch/bvz/berufe/index.html


class Provider(BaseProvider):
    jobs = [
        "Accompagnant socioprofessionnel diplômé",
        "Accompagnateur de randonnée avec brevet fédéral",
        "Accompagnateur social avec brevet fédéral",
        "Acousticien en systèmes auditifs CFC",
        "Administrateur diplomé de biens immobiliers",
        "Agent commercial de l'imprimerie avec brevet fédéral (BF)",
        "Agent d'entretien de bateaux",
        "Agent d'exploitation CFC",
        "Agent de détention avec brevet fédéral",
        "Agent de maintenance avec brevet fédéral",
        "Agent de processus avec brevet fédéral",
        "Agent de propreté AFP",
        "Agent de propreté CFC",
        "Agent de transport et logistique avec brevet fédéral",
        "Agent de transports publics CFC",
        "Agent de voyages avec brevet fédéral",
        "Agent d’entretien de bateaux CFC",
        "Agent d’entretien en assainissement AFP",
        "Agent d’exploitation CFC",
        "Agent en automatique avec brevet fédéral",
        "Agent en information documentaire CFC",
        "Agent en produits textiles AFP",
        "Agent fiduciaire avec brevet fédéral",
        "Agent professionnel de protection de personnes et de biens avec brevet fédéral",
        "Agent professionnel de sécurité et de surveillance avec brevet fédéral",
        "Agent relation client CFC",
        "Agent technico-commercial avec brevet fédéral",
        "Agent technique d'exploitation avec brevet fédéral",
        "Agent technique des matières synthétiques CFC",
        "Agriculteur CFC (Champ professionnel de l'agriculture)",
        "agrocommerçant diplômé ES",
        "Agropraticien AFP",
        "agrotechnicien diplômé ES",
        "Aide en informatique AFP",
        "Aide en soins et accompagnement AFP",
        "Aide en technique du bâtiment AFP",
        "Aide-carreleur AFP",
        "Aide-constructeur métallique AFP",
        "Aide-maçon AFP",
        "Aide-menuisier AFP",
        "Aide-monteur frigoriste AFP",
        "Aide-mouleur AFP",
        "Aide-peintre AFP",
        "Aide-plâtrier AFP",
        "Aide-polybâtisseur AFP",
        "ambulancier diplômé ES",
        "Analyste financier et gestionnaire de fortunes diplômé",
        "Arboriculteur CFC (Champ professionnel de l'agriculture)",
        "Armurier",
        "Armurier CFC",
        "Art-thérapeute diplômé (DF)",
        "Artisan du bois CFC",
        "Artisan du cuir et du textile CFC",
        "Artisan en conservation des monument historiques avec brevet fédéral",
        "Assistant de bureau AFP",
        "Assistant de direction avec brevet fédéral",
        "Assistant de gestion en pharmacie avec brevet fédéral",
        "Assistant dentaire CFC",
        "Assistant du commerce de détail AFP",
        "Assistant en audiovision avec brevet fédéral",
        "Assistant en boucherie et charcuterie AFP",
        "assistant en droit diplômé ES",
        "Assistant en maintenance d'automobiles AFP",
        "Assistant en médecine vétérinaire CFC",
        "Assistant en médias imprimés AFP",
        "Assistant en pharmacie CFC",
        "Assistant en podologie CFC",
        "Assistant en podologie CFC",
        "Assistant en promotion de l’activité physique et de la santé CFC",
        "Assistant en soins et santé communautaire CFC",
        "Assistant en tourisme avec brevet fédéral",
        "Assistant en traitement de surface AFP",
        "Assistant médical CFC",
        "Assistant socio-éducatif CFC",
        "Assistant spécialisé en soins de longue durée et accompagnement avec brevet fédéral",
        "Assistant vernisseur AFP",
        "Assistant-constructeur de fondations AFP (champ professionnel Construction de voies de communication)",
        "Assistant-constructeur de fondations AFP (champ professionnel Construction de voies de communication)",
        "Assistant-constructeur de routes AFP (champ professionnel Construction de voies de communication)",
        "Assistant-constructeur de routes AFP (champ professionnel Construction de voies de communication)",
        "Assistant-constructeur de sols industriels et de chapes AFP (champ professionnel Construction de voies de communication)",
        "Assistant-constructeur de sols industriels et de chapes AFP (champ professionnel Construction de voies de communication)",
        "Assistant-constructeur de voies ferrées AFP (champ professionnel Construction de voies de communication)",
        "Audioprothésiste avec brevet fédéral",
        "Automaticien CFC",
        "Aviculteur CFC (Champ professionnel de l'agriculture)",
        "Bijoutier CFC",
        "Bijoutier, maître",
        "Bottier-orthopédiste",
        "Bottier-orthopédiste CFC",
        "Bottier-orthopédiste diplômé, maître",
        "Boucher-charcutier CFC",
        "Boucher-charcutier, maître",
        "Boulanger-pâtissier-confiseur AFP",
        "Boulanger-pâtissier-confiseur CFC",
        "Cabin Crew Member avec brevet fédéral",
        "Cadre diplomé des organisations de secours",
        "Calorifugeur-tôlier",
        "Calorifugeur-tôlier CFC",
        "Calorifugeur-tôlier, maître",
        "Carreleur CFC",
        "Carreleur, maître",
        "Carrossier, maître",
        "Carrossier-peintre CFC",
        "Carrossier-tôlier CFC",
        "Caviste CFC (Champ professionnel de l'agriculture)",
        "Céramiste",
        "Céramiste CFC",
        "Céramiste industriel CFC",
        "Charpentier",
        "Charpentier CFC",
        "Charpentier, maître",
        "Charron",
        "Charron, maître",
        "Chef boulanger-pâtissier-confiseur avec brevet fédéral",
        "Chef carreleur avec brevet fédéral",
        "Chef confiseur-pâtissier-glacier avec brevet fédéral",
        "Chef cuisinier avec brevet fédéral",
        "Chef d'atelier en machines agricoles avec brevet fédéral",
        "Chef d'atelier en machines de chantier avec brevet fédéral",
        "Chef d'atelier d'appareils à moteur avec brevet fédéral",
        "Chef d'atelier et de montage en construction métallique avec brevet fédéral",
        "Chef d'entreprise de l'hôtellerie et de la restauration diplomé",
        "Chef d'entreprise diplomée en boulangerie-pâtisserie-confiserie",
        "Chef d'établissement de l'hôtellerie et de la restauration avec brevet fédéral",
        "Chef d'expédition diplômé",
        "Chef d'exploitation agricole avec brevet fédéral",
        "Chef d'exploitation arboricole avec brevet fédéral",
        "Chef d'exploitation avicole avec brevet fédéral",
        "Chef d'exploitation caviste avec brevet fédéral",
        "Chef d'exploitation économie carnée avec brevet fédéral",
        "Chef d'exploitation maraîchère avec brevet fédéral",
        "Chef d'exploitation viticole avec brevet fédéral",
        "Chef de commerce international diplômé",
        "Chef de cuisine avec diplôme fédéral",
        "Chef de la restauration avec diplôme fédéral",
        "Chef de la restauration collective avec diplôme fédéral",
        "Chef de logistique diplômé",
        "Chef de marketing diplômé",
        "Chef de production en menuiserie",
        "Chef de production technique des matières synthétiques diplômé",
        "Chef de projet en menuiserie",
        "Chef de projet en montage solaire avec brevet fédéral",
        "Chef de projet en technique du bâtiment avec brevet fédéral",
        "Chef de projet et chef d'atelier en construction de tableaux électriques avec brevet fédéral",
        "Chef de projet systèmes de sécurité avec brevet fédéral",
        "Chef de projet verre avec brevet fédéral",
        "Chef de projets constructeur sur métal avec diplôme fédéral",
        "Chef de réception avec brevet fédéral",
        "Chef de service après-vente diplômé",
        "Chef de vente diplômé",
        "Chef du secteur hôtelier-intendance avec diplôme fédéral",
        "Chef monteur-frigoriste avec brevet fédéral",
        "Chef poseur de revêtements de sols avec brevet fédéral",
        "Chef-monteur en échafaudage avec brevet fédéral",
        "Cidrier avec diplôme de maîtrise",
        "Coiffeur AFP",
        "Coiffeur avec brevet fédéral",
        "Coiffeur avec diplôme fédéral",
        "Coiffeur CFC",
        "Coiffeur CFC",
        "Coloriste avec brevet fédéral",
        "Concepteur artisan avec brevet fédéral",
        "Concepteur en multimédia",
        "Concierge avec brevet fédéral",
        "Conducteur d'engins forestier avec brevet fédéral",
        "Conducteur de camion",
        "Conducteur de véhicules légers AFP",
        "Conducteur de véhicules lourds CFC",
        "Confectionneur AFP",
        "Conseil en brevets",
        "Conseiller dans le domaine psychosocial avec diplôme fédéral",
        "Conseiller de service à la clientèle dans la branche automobile avec brevet fédéral",
        "Conseiller de vente automobile avec brevet fédéral",
        "Conseiller de vente en horlogerie avec brevet fédéral",
        "Conseiller en affections respiratoires et tuberculose avec brevet fédéral",
        "Conseiller en aménagement intérieur avec brevet fédéral",
        "Conseiller en couleurs et en styles de mode avec brevet fédéral",
        "Conseiller en énergie et en efficacité énergétique avec diplôme fédéral",
        "Conseiller en environnement avec brevet federal",
        "Conseiller en milieu rural diplômé",
        "Conseiller en organisation avec diplôme fédéral",
        "Conseiller en relations publiques avec diplôme fédéral",
        "Conseiller en revêtements de sols avec brevet fédéral",
        "Conseiller en sécurité électrique avec brevet fédéral",
        "Conseiller énergétique du bâtiment avec brevet fédéral",
        "Conseiller financier avec brevet fédéral",
        "Constructeur de ski (LU)",
        "Constructeur d'appareils industriels",
        "Constructeur d'éléments en béton préfabriqués CFC",
        "Constructeur d'installation de ventilation CFC",
        "Constructeur de bateaux",
        "Constructeur de bateaux CFC",
        "Constructeur de fondations CFC (champ professionnel Construction de voies de communication)",
        "Constructeur de fondations CFC (champ professionnel Construction de voies de communication)",
        "Constructeur de routes CFC (champ professionnel Construction de voies de communication)",
        "Constructeur de routes CFC (champ professionnel Construction de voies de communication)",
        "Constructeur de sols industriels et de chapes CFC (champ professionnel Construction de voies de communication)",
        "Constructeur de sols industriels et de chapes CFC (champ professionnel Construction de voies de communication)",
        "Constructeur de voies ferrées CFC (champ professionnel Construction de voies de communication)",
        "Constructeur de voies ferrées CFC (champ professionnel Construction de voies de communication)",
        "Constructeur d’appareils industriels CFC",
        "Constructeur métallique CFC",
        "Constructeur métallique, maître",
        "Constructeur naval, maître",
        "Contact Center Supervisor avec brevet fédéral",
        "Contremaître charpentier avec brevet fédéral",
        "Contremaître de construction de fondations avec brevet fédéral (champ professionnel Construction de voies de communication)",
        "Contremaître de construction de routes avec brevet fédéral (champ professionnel Construction de voies de communication)",
        "Contremaître de construction de sols industriels et de chapes avec brevet fédéral (champ professionnel Construction de voies de communication)",
        "Contremaître de sciage d'édifice avec brevet fédéral",
        "Contremaître de voies ferrées avec brevet fédéral (champ professionnel Construction de voies de communication)",
        "Contremaître en chauffage avec brevet fédéral",
        "Contremaître en entretien de routes avec brevet fédéral (champ professionnel Construction de voies de communication)",
        "Contremaître en ferblanterie avec brevet fédéral",
        "Contremaître en ventilation avec brevet fédéral",
        "Contremaître forestier avec brevet fédéral",
        "Contremaître jardinier avec brevet fédéral",
        "Contremaître maçon avec brevet fédéral",
        "Contremaître paveur avec brevet fédéral (champ professionnel Construction de voies de communication)",
        "Contremaître peintre avec brevet fédéral",
        "Contremaître plâtrier-constructeur à sec avec brevet fédéral",
        "Contremaître Polybat avec brevet fédéral",
        "Contremaître ramoneur avec brevet fédéral",
        "Contremaître sanitaire avec brevet fédéral",
        "Contremaître vitrier avec brevet fédéral",
        "Contrôleur de combustion avec brevet fédéral",
        "contrôleur de la circulation aérienne diplomé ES",
        "Contrôleur de matériaux de construction avec brevet fédéral",
        "Coordinateur d'atelier automobile avec brevet fédéral",
        "Coordinateur en médecine ambulatoire orientation clinique avec brevet fédéral",
        "Coordinateur en médecine ambulatoire orientation gestion avec brevet fédéral",
        "Cordonnier CFC",
        "Cordonnier, maître",
        "Correcteur avec brevet fédéral (BF)",
        "Courtepointier CFC",
        "Courtepointier diplômé",
        "Courtier en immeubles avec brevet fédéral",
        "Coutelier",
        "Coutelier CFC",
        "Coutelier, maître",
        "Couturier avec brevet fédéral",
        "Couturier diplômé",
        "couturier d’intérieur AFP",
        "Créateur de textiles intérieurs avec brevet fédéral",
        "Créateur de tissu CFC",
        "Créateur de vêtements",
        "Créateur de vêtements CFC",
        "Croupier avec brevet fédéral",
        "Cuisinier CFC",
        "Cuisinier en diététique CFC",
        "Danseur interprète CFC",
        "Déclarant de douane avec brevet fédéral",
        "Décorateur d'intérieur avec brevet fédéral",
        "Décorateur d'intérieurs",
        "Décorateur d'intérieurs diplômé",
        "Dermapigmentologue avec brevet fédéral",
        "designer diplômé ES en arts visuels",
        "designer diplômé ES en communication visuelle",
        "designer diplômé ES en design de produit",
        "Designer graphique diplomé",
        "Dessinateur CFC (champ professionnel planification du territoireet de la construction)",
        "Dessinateur en construction microtechnique CFC",
        "Dessinateur-constructeur en génie civil diplômé",
        "Dessinateur-constructeur en microtechnique",
        "Dessinateur-constructeur industriel CFC",
        "Dessinateur-constructeur sur métal CFC",
        "Développeur immobilier avec brevet fédéral",
        "Diagnosticien d'automobiles avec brevet fédéral",
        "dipl. Abteilungsleiter Gesundheit NDS HF",
        "dipl. Baubetriebsmanager NDS HF",
        "dipl. Bauprojekt- und Immobilienmanager NDS HF",
        "dipl. Berater in Veränderungsprozessen NDS HF",
        "dipl. Betriebswirtschafter NDS HF",
        "dipl. Business Analyst NDS HF",
        "dipl. Business Banker NDS HF",
        "dipl. Business Coach NDS HF",
        "dipl. Business Engineer NDS HF",
        "dipl. Controller NDS HF",
        "dipl. Energieberater NDS HF",
        "dipl. Erlebnispädagoge NDS HF",
        "dipl. Experte in Leadership und Change Management NDS HF",
        "dipl. Experte in strategischem Management NDS HF",
        "dipl. Finanzchef NDS HF",
        "dipl. Finanzexperte NDS HF",
        "dipl. Geschäftsführer NDS HF",
        "dipl. Hotelmanager NDS HF",
        "dipl. HR-Experte NDS HF",
        "dipl. Human Resource Manager NDS HF",
        "dipl. in Leadership und Management NDS HF",
        "dipl. in Unternehmens- und Mitarbeiterführung NDS HF",
        "dipl. IT-Service-Manager NDS HF",
        "dipl. Kommunikationstrainer NDS HF",
        "dipl. Leiter Finanzen und Dienste NDS HF",
        "dipl. Leiter interne Kommunikation und Management Support NDS",
        "dipl. Logistikleiter NDS HF",
        "dipl. logotherapeutischer Berater NDS HF",
        "dipl. Marketing- und Verkaufsleiter NDS HF",
        "dipl. Marketing- und Verkaufsmanager NDS HF",
        "dipl. Marketingmanager NDS HF",
        "dipl. Network Engineer NDS HF",
        "dipl. Online-Marketingmanager NDS HF",
        "dipl. Personalleiter NDS HF",
        "dipl. Produktmanager Textil NDS HF",
        "dipl. Projekt- und Prozessmanager NDS HF",
        "dipl. Projektleiter NDS HF",
        "dipl. Projektmanager NDS HF",
        "dipl. Qualitäts- und Prozessmanager NDS HF",
        "dipl. Qualitätsmanager NDS HF",
        "dipl. Umfassende Leadership NDS HF",
        "dipl. Umfassendes Controlling NDS HF",
        "dipl. Unternehmensführer NDS HF",
        "dipl. Unternehmensleiter NDS HF",
        "Diplom in Energiemanagement NDS HF",
        "Diplom in Unternehmensführung NDS HF",
        "Directeur d'école d'une discipline sportive avec diplôme fédéral",
        "Directeur d'institution de l'enfance diplômé EPD ES",
        "Directeur d'institution sociale et médico-sociale diolomé",
        "Directeur de studio de gymnastique avec brevet fédéral",
        "Directeur des travaux du bâtiment diplômé",
        "Directeur des travaux du génie civil diplômé",
        "Dirigeant d'entreprise avec diplôme fédéral",
        "Dirigeant de maintenance diplômé",
        "Dirigeant diplomé en facility management",
        "Doreur-Encadreur CFC",
        "Droguiste CFC",
        "Ebéniste CFC",
        "Ebéniste, maître",
        "Ecobiologiste de la construction avec brevet fédéral",
        "Ecobiologiste de la construction diplômé",
        "économiste bancaire diplomé ES",
        "économiste d'assurance diplômé ES",
        "économiste d'entreprise diplômé ES",
        "Economiste d'entreprise PME avec diplôme fédéral",
        "éducateur de l'enfance diplômé. ES",
        "éducateur social diplomé ES",
        "éducateur social diplômé ES",
        "Electricien chef de projet avec brevet fédéral",
        "Electricien de montage CFC",
        "Electricien de montage CFC",
        "Electricien de réseau",
        "Electricien de réseau CFC",
        "Electricien de réseau, maître, diplomé",
        "Electronicien CFC",
        "Electronicien en multimédia",
        "Electronicien en multimédia avec brevet fédéral",
        "Electronicien en multimédia CFC",
        "Electroplaste avec brevet fédéral",
        "Electroplaste CFC",
        "Electroplaste diplômé",
        "Employé de commerce",
        "Employé de commerce CFC",
        "Employé de remontées mécaniques AFP",
        "Employé d’exploitation AFP",
        "Employé en cuisine AFP",
        "Employé en hôtellerie AFP",
        "Employé en industrie laitière AFP",
        "Employé en intendance AFP",
        "Employé en intendance AFP",
        "Employé en restauration AFP",
        "Enquêteur de douane avec diplôme fédéral",
        "Entraîneur de sport de performance avec brevet fédéral",
        "Entraîneur diplômé de sport d'Elite",
        "Entrepreneur de pompes funèbres avec brevet fédéral",
        "Entrepreneur-construction diplômé",
        "Esthéticien avec brevet fédéral",
        "Esthéticien CFC",
        "Esthéticien diplômé",
        "Expert diplômé en assurance-maladie",
        "Expert diplômé en assurances de pension",
        "Expert diplômé en assurances sociales",
        "Expert diplômé en conduite organisationelle",
        "Expert diplômé en finance et en controlling",
        "Expert diplômé en finance et investissements",
        "Expert diplômé en tourisme",
        "Expert domaine opératoire avec diplôme fédéral",
        "Expert du domaine des privations de liberté avec diplôme fédéral",
        "Expert du domaine éguin avec diplôme fédéral",
        "Expert en analyses biomédicales et gestion de laboratoire avec diplôme fédéral",
        "Expert en cytodiagnostic avec diplôme fédéral",
        "Expert en douane diplomé ES",
        "Expert en estimations immobilières avec brevet fédéral",
        "Expert en finance de PME avec diplôme fédéral",
        "Expert en gestion hospitalière avec diplôme fédéral",
        "Expert en management de l'organisation avec diplôme fédéral",
        "Expert en opérations des marchés financiers avec diplôme fédéral",
        "Expert en prévention des infections associées aux soins avec diplôme fédéral",
        "Expert en production avec brevet fédéral",
        "Expert en soins d’anesthésie diplômé EPD ES",
        "Expert en soins d’urgence diplômé EPD ES",
        "Expert en soins intensifs diplômé EPD ES",
        "Expert fiduciaire diplômé",
        "Expert fiscal diplômé",
        "Expert protection incendie avec diplôme fédéral",
        "Expert-comptable diplômé",
        "Expert-soudeur avec brevet fédéral",
        "Exploitant de station d'épuration avec brevet fédéral",
        "Facteur d'instruments de musique CFC",
        "Fashion spécialiste avec brevet fédéral",
        "Fashiondesigner avec diplôme fédéral",
        "Ferblantier CFC",
        "Fleuriste AFP",
        "Fleuriste avec brevet fédéral",
        "Fleuriste CFC",
        "Fleuriste, maître",
        "Flexographe CFC",
        "Fontainier avec brevet fédéral",
        "forestier diplômé ES",
        "Forestier-bûcheron CFC",
        "Forgeron, maître",
        "Formateur avec brevet fédéral",
        "Fourreur, maître",
        "Gainier",
        "Garde-faune avec brevet fédéral",
        "Garde-frontière avec brevet fédéral",
        "Garde-frontière avec diplôme fédéral",
        "Garde-pêche avec brevet fédéral",
        "Gardien d'immeuble diplômé",
        "Gardien de cheval AFP",
        "Gardien de chevaux AFP",
        "Gardien d’animaux CFC",
        "Garnisseur de meubles CFC",
        "Garnisseur de meubles industriels avec brevet fédéral",
        "Garnisseur de meubles industriels, maître",
        "Garnisseur de meubles spécialisé avec brevet fédéral",
        "Garnisseur en carrosserie",
        "Géomaticien CFC",
        "Gérant d'immeubles avec brevet fédéral",
        "Gérant de caisse de pension diplômé",
        "Gestionnaire d'entreprise diplômé de la branche automobile",
        "Gestionnaire d'entreprise diplômé secteur automobile",
        "Gestionnaire du commerce de détail CFC",
        "Gestionnaire en intendance CFC",
        "Gestionnaire en intendance CFC",
        "Gestionnaire en tourisme de santé et d'activité avec diplôme fédéral",
        "gestionnaire en tourisme diplômé ES",
        "Gouvernant de maison avec brevet fédéral",
        "Graphiste CFC",
        "Graveur",
        "Graveur CFC",
        "Guide de montagne avec brevet fédéral",
        "Guide touristique avec brevet fédéral",
        "Horloger CFC",
        "Horloger dans le domaine professionnel de l'industrie",
        "Horloger dans le domaine professionnel du rhabillage",
        "Horloger de production CFC",
        "Horloger praticien",
        "Horloger, maître",
        "Horticulteur",
        "Horticulteur AFP",
        "Horticulteur CFC",
        "Hôtelier-Restaurateur diplômé ES",
        "hygiéniste dentaire diplômé ES",
        "ICT-Manager diplomé",
        "infirmier diplômé ES",
        "infirmier diplômé ES",
        "Informaticien CFC",
        "Informaticien CFC",
        "Informaticien de gestion avec brevet fédéral",
        "informaticien de gestion diplômé ES",
        "Informaticien en développement d'application TIC avec brevet fédéral",
        "Informaticien en technique des systèmes et réseaux TIC avec brevet fédéral",
        "Installateur en chauffage CFC",
        "Installateur sanitaire CFC",
        "Installateur-électricien CFC",
        "Installateur-électricien CFC",
        "Installateur-électricien diplômé",
        "Instructeur de chiens guides d'aveugles avec diplôme fédéral",
        "Instructeur de fitness avec brevet fédéral",
        "intendant du secteur hôtelier d'établissement diplômé ES",
        "Interactive Media Designer CFC",
        "Key account manager diplômé",
        "Laborantin CFC",
        "Laborantin en physique",
        "Laborantin en physique CFC",
        "Laboriste",
        "Libraire avec brevet fédéral",
        "Libraire CFC",
        "Logisticien AFP",
        "Logisticien AFP",
        "Logisticien avec brevet fédéral",
        "Logisticien avec brevet fédéral",
        "Logisticien avec diplôme fédéral",
        "Logisticien CFC",
        "Logisticien CFC",
        "Luthier",
        "Luthier, maître",
        "Maçon CFC",
        "Maître agriculteur",
        "Maître arboriculteur",
        "Maître aviculteur",
        "Maître caviste",
        "Maître chauffagiste avec diplôme fédéral",
        "Maître dans l'industrie",
        "Maître du cuir et du textile",
        "Maître ferblantier avec diplôme fédéral",
        "Maître jardinier",
        "Maître maraîcher",
        "Maître peintre",
        "Maître Polybat",
        "Maître poseur de revêtements de sols",
        "Maître Ramoneur",
        "Maître sanitaire avec diplôme fédéral",
        "Maître scultpeur sur bois",
        "maître socioprofessionnel diplômé ES",
        "Maître tableaux électriques et automation",
        "Maître textile avec diplôme fédéral",
        "Maître viticulteur",
        "Maître vitrier",
        "Manager de médias diplômé",
        "Manager de remontées mécanique avec diplôme fédéral",
        "Manager en commerce de détail avec diplôme fédéral",
        "Manager en publication avec diplôme fédéral (DF)",
        "Manager en systèmes de transports publics diplômé",
        "Maquettiste d'architecture",
        "Maquilleur professionnel avec brevet fédéral",
        "Maraîcher CFC (Champ professionnel de l'agriculture)",
        "Marbrier CFC (Champ professionnel travail de la pierre)",
        "Marbrier du bâtiment CFC (Champ professionnel travail de la pierre)",
        "Marbrier, maître",
        "Maréchal-ferrant CFC",
        "Maréchal-forgeron, maître",
        "marketing manager diplômé ES",
        "Masseur médical avec brevet fédéral",
        "Matelot de la navigation intérieure CFC",
        "Mécanicien d'appareils à moteur CFC",
        "Mécanicien d'appareils à moteur, maître",
        "Mécanicien de production CFC",
        "Mécanicien deux-roues",
        "Mécanicien en bicyclettes et motocyclettes, maître",
        "Mécanicien en bicyclettes, maître",
        "Mécanicien en cycles CFC",
        "Mécanicien en machines agricoles CFC",
        "Mécanicien en machines agricoles, maître",
        "Mécanicien en machines de chantier CFC",
        "Mécanicien en machines de chantier, maître",
        "Mécanicien en maintenance d'automobiles CFC",
        "Mécanicien en motocycles",
        "Mécanicien en motocycles CFC",
        "Mécanicien en motocycles de petite cylindrée et cycles CFC",
        "Mécatronicien d'automobiles CFC",
        "Mécatronicien de remontées mécaniques CFC",
        "Médiamaticien",
        "Médiamaticien avec brevet fédéral",
        "Médiamaticien CFC",
        "Mentor d'entreprise avec brevet fédéral",
        "Menuisier, maître",
        "Menuisier",
        "Meunier",
        "Meunier CFC",
        "Micromécanicien",
        "Micromécanicien CFC",
        "Modeleur-céramiste",
        "Moniteur de conduite avec brevet fédéral",
        "Monteur automaticien CFC",
        "Monteur de faux plafonds avec brevet fédéral",
        "Monteur de réseaux eau et gaz avec brevet fédéral",
        "Monteur frigoriste CFC",
        "Monteur-frigoriste",
        "Mouleur CFC",
        "Mouleur de fonderie",
        "Mouleur de fonderie CFC",
        "Naturopathe avec diplôme fédéral",
        "Négociant de vins diplômé",
        "Nettoyeur chimique diplômé",
        "Nettoyeur de bâtiments diplomé",
        "Nettoyeur de textiles CFC",
        "Officier de l'état civil avec brevet fédéral",
        "Opérateur d'installations de centrale nucléaire avec brevet fédéral",
        "Opérateur de machines automatisées CFC",
        "Opérateur de médias imprimés CFC",
        "Opérateur de sciage d’édifice CFC",
        "Opérateur en horlogerie AFP",
        "Opérateur en horlogerie AFP",
        "Opticien CFC",
        "Opticien en instruments",
        "Opticien en instruments de précision CFC",
        "Orfèvre en argenterie, maître",
        "Orthopédiste CFC",
        "Orthopédiste diplômé",
        "orthoptiste diplômé ES",
        "Packaging Manager avec diplôme fédéral",
        "Papetier",
        "Papetier CFC",
        "Pâtissier-confiseur diplômé",
        "Paveur CFC (champ professionnel Construction de voies de communication)",
        "Paveur CFC (champ professionnel Construction de voies de communication)",
        "Paveur, maître",
        "Pêcheur professionnel avec brevet fédéral",
        "Peintre CFC",
        "Peintre en automobiles avec brevet fédéral",
        "Peintre en bâtiments",
        "Peintre en décors de théâtre",
        "Peintre en décors de théâtre CFC",
        "Peintre verrier CFC",
        "Photodesigner diplomé",
        "Photographe",
        "Photographe CFC",
        "Photographe de laboratoire",
        "Physiothérapeut pour animaux avec diplôme fédéral",
        "pilote diplômé ES",
        "Planificateur éclairagiste avec brevet fédéral",
        "Planificateur en communication avec brevet fédéral",
        "Planificateur-électricien CFC",
        "Planificateur-électricien CFC",
        "Planificateur-électricien diplômé",
        "Plâtrier",
        "Plâtrier constructeur à sec CFC",
        "Plâtrier, maître",
        "Plâtrier-peintre",
        "podologue diplômé ES",
        "Poêlier-fumiste CFC",
        "Poêlier-fumiste, maître",
        "Poêlier-fumiste, maître",
        "Policier avec brevet fédéral",
        "Policier avec diplôme fédéral",
        "Polisseur AFP",
        "Polybâtisseur CFC",
        "Polydesigner 3D CFC",
        "Polygraphe CFC",
        "Polygraphe CFC",
        "Polymécanicien CFC",
        "Poseur de pierres AFP (champ professionnel Construction de voies de communication)",
        "Poseur de pierres AFP (champ professionnel Construction de voies de communication)",
        "Poseur de revêtements de sols",
        "Poseur de sol – parquet CFC",
        "Praticien des matières synthétiques AFP",
        "Praticien en denrées alimentaires AFP",
        "Praticien en mécanique AFP",
        "Praticien en pneumatiques AFP",
        "Praticien forestier AFP",
        "Praticien sur bois AFP",
        "Préparateur Humains avec brevet fédéral",
        "Professeur d'escalade avec brevet fédéral",
        "Professeur de canoë-kayak avec brevet fédéral",
        "Professeur de danse de couple avec brevet fédéral",
        "Professeur de golf avec brevet fédéral",
        "Professeur de ju-jitsu avec brevet fédéral",
        "Professeur de judo avec brevet fédéral",
        "Professeur de karaté avec brevet fédéral",
        "Professeur de patinage avec brevet fédéral",
        "Professeur de planche à voile avec brevet fédéral",
        "Professeur de sport de neige avec brevet fédéral",
        "Professeur de sports aquatiques avec brevet fédéral",
        "Professeur de tennis avec brevet fédéral",
        "Professeur de voile avec brevet fédéral",
        "Professeur en navigation de bateau moteur avec brevet fédéral",
        "Professionnel du cheval CFC",
        "Professionnel du cheval CFC",
        "Projeteur constructeur sur métal avec brevet fédéral",
        "Projeteur en sanitaire avec diplôme fédéral",
        "Projeteur en technique du bâtiment",
        "Projeteur en technique du bâtiment chauffage CFC (champ professionnel Planification en technique du bâtiment)",
        "Projeteur en technique du bâtiment sanitaire CFC (champ professionnel Planification en technique du bâtiment)",
        "Projeteur en technique du bâtiment ventilation CFC (champ professionnel Planification en technique du bâtiment)",
        "Projeteur frigoriste CFC",
        "Ramoneur CFC",
        "Réalisateur publicaire avec diplôme fédéral",
        "Réalisateur publicitaire CFC",
        "Réalisateur publicitaire CFC",
        "Recycleur CFC",
        "Rédacteur publicitaire avec brevet fédéral",
        "Rédacteur technique avec brevet fédéral",
        "Réparateur de chaussures AFP",
        "Repousseur-emboutisseur",
        "Responsable Achats avec diplôme fédéral",
        "Responsable d'équipe dans des institutions sociales et médico-sociales avec brevet fédéral",
        "Responsable de formation avec diplôme fédéral",
        "Responsable de la communication diplomé",
        "Responsable de la restauration avec brevet fédéral",
        "Responsable de ménage agricole avec brevet fédéral",
        "Responsable de ménage agricole diplomé",
        "Responsable diplômé en documentation technique",
        "Responsable du secteur hôtelier - intendance avec brevet fédéral",
        "Responsable en transport et logistique diplômé",
        "Responsable diplômé en ressources humaines",
        "Restaurateur de livres diplômé",
        "Sapeur-pompier professionnel avec brevet fédéral",
        "Scieur de l'industrie du bois CFC",
        "Screen Communicator avec brevet fédéral",
        "Sculpteur sur bois CFC",
        "Sculpteur sur pierre CFC (Champ professionnel travail de la pierre)",
        "Sculpteur sur pierre, maître",
        "Secouriste routier avec brevet féderal",
        "Sellier",
        "Sérigraphe, maître",
        "Serrurier sur véhicules avec brevet fédéral",
        "Serrurier sur véhicules CFC",
        "Sertisseur en joaillerie, maître",
        "Sommelier avec brevet fédéral",
        "Specialista in soluzioni mobile aziendali dipl. SPD SSS",
        "Spécialiste assainissement d'ouvrage avec brevet federal",
        "Spécialiste câble-crue avec brevet fédéral",
        "Spécialiste d'achat",
        "Spécialiste de commerce international avec brevet fédéral",
        "Spécialiste de douane avec brevet fédéral",
        "Spécialiste de la conduite d'équipe avec brevet fédéral",
        "Spécialiste de la gestion et du développement des organisations syndicales avec brevet fédéral",
        "Spécialiste de la migration avec brevet fédéral",
        "Spécialiste de la nature et de l'environnement avec brevet fédéral",
        "Spécialiste de la prévoyance en faveur du personnel avec brevet fédéral",
        "Spécialiste de la sécurité dans les institutions de santé et du social avec brevet fédéral",
        "Spécialiste de logistique avec brevet fédéral",
        "Spécialiste de médias avec brevet fédéral",
        "Spécialiste de réseau avec brevet fédéral",
        "Spécialiste de traitement des matières premières avec brevet fédéral",
        "Spécialiste de vente avec brevet federal",
        "Spécialiste des branches de la boulangerie-pâtisserie-confiserie avec brevet fédéral",
        "Spécialiste des installations de transport à câbles avec brevet fédéral",
        "spécialiste des services de la navigation aérienne diplomé ES",
        "Spécialiste du commerce de détail avec brevet fédéral",
        "Spécialiste du commerce fruits et légumes avec brevet fédéral",
        "Spécialiste du domain équin avec brevet fédéral",
        "Spécialiste du service de pistes et de sauvetage avec brevet fédéral",
        "spécialiste en activation diplômé ES",
        "Spécialiste en administration publique avec brevet fédéral",
        "Spécialiste en agriculture biodynamique avec brevet fédéral",
        "Spécialiste en assurance avec brevet fédéral",
        "Spécialiste en assurance-maladie avec brevet fédéral",
        "Spécialiste en assurances sociales avec brevet fédéral",
        "Spécialiste en bois avec brevet fédéral",
        "Spécialiste en codage médical avec brevet fédéral",
        "Spécialiste en commerce de textile avec brevet fédéral",
        "Spécialiste en diagnostic neurophysiologique avec brevet fédéral",
        "Spécialiste en finance et comptabilité avec brevet fédéral",
        "Spécialiste en finition des médias imprimés avec brevet fédéral (BF)",
        "Spécialiste en formation professionnelle avec brevet fédéral",
        "Spécialiste en gestion de PME avec brevet fédéral",
        "Spécialiste en gestion hospitalière avec brevet fédéral",
        "Spécialiste en hôtellerie CFC",
        "Spécialiste en impression et emballage avec brevet fédéral (BF)",
        "Spécialiste en interprétariat communautaire et médiation interculturelle avec brevet fédéral",
        "Spécialiste en marketing avec brevet fédéral",
        "Spécialiste en matière de poursuite pour dettes et de la faillite avec brevet fédéral",
        "Spécialiste en nettoyage de bâtiments avec brevet fédéral",
        "Spécialiste en organisation d'entreprise avec brevet fédéral",
        "Spécialiste en photographie avec brevet fédéral",
        "Spécialiste en photographie CFC",
        "Spécialiste en photographie diplômé",
        "Spécialiste en pneumatiques avec brevet fédéral",
        "Spécialiste en protection incendie avec brevet fédéral",
        "Spécialiste en réadaptation de personnes malvoyantes et aveugles avec diplôme fédéral",
        "Spécialiste en relations publiques avec brevet fédéral",
        "Spécialiste en ressources humaines avec brevet fédéral",
        "Spécialiste en restauration CFC",
        "Spécialiste en restauration de système CFC",
        "Spécialiste en soin aux arbres avec brevet fédéral",
        "Spécialiste en systèmes thermiques avec brevet fédéral",
        "Spécialiste en technologies de réadaptation avec brevet fédéral",
        "Spécialiste en thermique avec brevet fédéral",
        "Spécialiste en transports publics avec brevet fédéral",
        "Spécialiste en vernissage industriel avec brevet fédéral",
        "Spécialiste établissements de bains avec brevet fédéral",
        "Spécialiste minage avec brevet fédéral",
        "Spécialiste pharmaceutique avec brevet fédéral",
        "Spécialiste pour installations de traitement des déchets avec brevet fédéral",
        "Spécialiste pour la sécurité des citernes avec brevet fédéral",
        "Styliste d'ongles avec brevet fédéral",
        "Superviseur-Coach avec diplôme fédéral",
        "Supply Chain Manager diplomé",
        "Tailleur de pierre CFC (Champ professionnel travail de la pierre)",
        "Tailleur, maître",
        "Technicien ambulancier avec brevet fédéral",
        "Technicien de fouilles archéologiques avec brevet fédéral",
        "Technicien de laboratoire en sciences naturelles avec diplôme fédéral",
        "technicien diplômé ES agroalimentaire",
        "technicien diplômé ES en informatique",
        "technicien diplômé ES en microtechnique",
        "technicien diplômé ES en télécommunications",
        "technicien diplômé ES génie électrique",
        "technicien diplômé ES génie mécanique",
        "technicien diplômé ES planification des travaux",
        "technicien diplomé ES processus d'entreprise",
        "technicien diplômé ES systèmes industriels",
        "technicien diplômé ES technique des bâtiments",
        "technicien diplômé ES technique du bois",
        "Technicien du film avec brevet fédéral",
        "Technicien du son avec brevet fédéral",
        "Technicien du spectacle avec brevet fédéral",
        "technicien en analyses biomédicales diplômé ES",
        "Technicien en géomatique avec brevet fédéral",
        "technicien en radiologie médicale diplômé ES",
        "technicien en salle d’opération diplômé ES",
        "Technicien sur aéronefs avec brevet fédéral",
        "Technicien vitivinicole dipl. ES",
        "Technicien-dentiste CFC",
        "Technicien-dentiste, maître",
        "Techniscéniste CFC",
        "Techno-polygraphe avec brevet fédéral (BF)",
        "Technologue de fonderie",
        "Technologue de fonderie CFC",
        "Technologue du lait CFC",
        "Technologue en assainissement CFC",
        "Technologue en chimie diplômé",
        "Technologue en denrées alimentaires",
        "Technologue en denrées alimentaires avec brevet fédéral",
        "Technologue en denrées alimentaires avec diplôme fédéral",
        "Technologue en denrées alimentaires CFC",
        "Technologue en emballage CFC",
        "Technologue en impression CFC",
        "Technologue en industrie laitière",
        "Technologue en industrie laitière avec brevet fédéral",
        "Technologue en industrie laitière diplomé",
        "Technologue en production chimique et pharmaceutique CFC",
        "Technologue en production chimique et pharmaceutique CFC",
        "Technologue en textile CFC",
        "Télématicien CFC",
        "Télématicien CFC",
        "Télématicien chef de projet avec brevet fédéral",
        "Télématicien diplômé",
        "Termineur en habillage horloger CFC",
        "Thérapeute Complémentaire avec diplôme fédéral",
        "Thermiste avec brevet fédéral",
        "Tôlier en carrosserie avec brevet fédéral",
        "Tonnelier CFC",
        "Tourneur, maître",
        "Transitaire avec brevet fédéral",
        "Typographiste pour la communication visuelle avec brevet fédéral",
        "Vannier créateur CFC",
        "Vérificateur des poids et mesures diplômé",
        "Vernisseur industriel CFC",
        "Vernisseur industriel CFC",
        "Viticulteur CFC (Champ professionnel de l'agriculture)",
        "Vitrier",
        "Vitrier CFC",
        "Web Project Manager diplômé",
        "Zingueur avec brevet fédéral",
        "Zingueur diplômé",

    ]



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as AddressProvider


class Provider(AddressProvider):

    building_number_formats = ('###', '##', '#')

    street_name_formats = ('{{street_prefix}}{{street_suffix}}', )

    street_address_formats = ('{{street_name}} {{building_number}}',)

    street_prefixes = (
        'Björk', 'Järnvägs', 'Ring', 'Skol', 'Skogs', 'Ny', 'Gran', 'Idrotts',
        'Stor', 'Kyrk', 'Industri', 'Park', 'Strand', 'Skol', 'Trädgårds',
        'Industri', 'Ängs', 'Kyrko', 'Park', 'Villa', 'Ek', 'Kvarn', 'Stations',
        'Back', 'Furu', 'Gen', 'Fabriks', 'Åker', 'Bäck', 'Asp'
    )

    street_suffixes = ('gatan', 'gatan', 'vägen', 'vägen',
                       'stigen', 'gränd', 'torget')

    address_formats = ("{{street_address}}\n{{postcode}} {{city}}", )

    postcode_formats = ('#####', )

    city_formats = ('{{city_name}}', )

    cities = (
        'Stockholm', 'Göteborg', 'Malmö', 'Uppsala', 'Västerås', 'Örebro',
        'Linköping', 'Helsingborg', 'Jönköping', 'Norrköping', 'Lund', 'Umeå',
        'Gävle', 'Borås', 'Mölndal', 'Södertälje', 'Eskilstuna', 'Karlstad',
        'Halmstad', 'Växjö', 'Sundsvall', 'Luleå', 'Trollhättan', 'Östersund',
        'Borlänge', 'Falun', 'Kalmar', 'Skövde', 'Kristianstad', 'Karlskrona',
        'Skellefteå', 'Uddevalla', 'Lidingö', 'Motala', 'Landskrona',
        'Örnsköldsvik', 'Nyköping', 'Karlskoga', 'Varberg', 'Trelleborg',
        'Lidköping', 'Alingsås', 'Piteå', 'Sandviken', 'Ängelholm'
    )

    countries = (
        'Afghanistan', 'Albanien', 'Algeriet', 'Amerikanska Samoa', 'Andorra',
        'Angola', 'Anguilla', 'Antarktis', 'Antigua och Barbuda', 'Argentina',
        'Armenien', 'Aruba', 'Ascension', 'Australien', 'Azerbajdzjan',
        'Bahamas', 'Bahrain', 'Bangladesh', 'Barbados', 'Belgien', 'Belize',
        'Benin', 'Bermuda', 'Bhutan', 'Bolivia', 'Bosnien och Hercegovina',
        'Botswana', 'Brasilien', 'Brittiska Jungfruöarna', 'Brunei',
        'Bulgarien', 'Burkina Faso', 'Burma', 'Burundi', 'Caymanöarna',
        'Centralafrikanska republiken', 'Chile', 'Colombia', 'Cooköarna',
        'Costa Rica', 'Cypern', 'Danmark', 'Diego Garcia', 'Djibouti',
        'Dominica', 'Dominikanska republiken', 'Ecuador', 'Egypten',
        'Ekvatorialguinea', 'Elfenbenskusten', 'El Salvador', 'Eritrea',
        'Estland', 'Etiopien', 'England', 'Falklandsöarna', 'Fiji',
        'Filippinerna', 'Finland', 'Frankrike', 'Franska Guyana',
        'Franska Polynesien', 'Färöarna', 'Förenade Arabemiraten', 'Gabon',
        'Gambia', 'Georgien', 'Ghana', 'Gibraltar', 'Grekland', 'Grenada',
        'Grönland', 'Guadeloupe', 'Guatemala', 'Guinea', 'Guinea-Bissau',
        'Guyana', 'Haiti', 'Honduras', 'Hongkong', 'Indien', 'Indonesien',
        'Irak', 'Iran', 'Irland', 'Island', 'Israel', 'Italien', 'Jamaica',
        'Japan', 'Jemen', 'Jordanien', 'Kambodja', 'Kamerun', 'Kanada',
        'Kap Verde', 'Kazakstan', 'Kenya', 'Kina', 'Kirgizistan', 'Kiribati',
        'Komorerna', 'Kongo-Brazzaville', 'Kongo-Kinshasa', 'Kosovo',
        'Kroatien', 'Kuba', 'Kuwait', 'Laos', 'Lesotho', 'Lettland', 'Libanon',
        'Liberia', 'Libyen', 'Liechtenstein', 'Litauen', 'Luxemburg', 'Macao',
        'Madagaskar', 'Makedonien', 'Malawi', 'Malaysia', 'Maldiverna', 'Mali',
        'Malta', 'Marianerna', 'Marocko', 'Marshallöarna', 'Martinique',
        'Mauretanien', 'Mauritius', 'Mayotte', 'Mexiko', 'Midwayöarna',
        'Mikronesiens federerade stater', 'Moçambique', 'Moldavien', 'Monaco',
        'Mongoliet', 'Montenegro', 'Montserrat', 'Namibia', 'Nauru',
        'Nederländerna', 'Nederländska Antillerna', 'Nepal',
        'Nicaragua', 'Niger', 'Nigeria', 'Niue', 'Nordkorea', 'Nordmarianerna',
        'Norfolkön', 'Norge', 'Nya Kaledonien', 'Nya Zeeland', 'Oman',
        'Pakistan', 'Palau', 'Palestina', 'Panama', 'Papua Nya Guinea',
        'Paraguay', 'Peru', 'Pitcairnöarna', 'Polen', 'Portugal', 'Qatar',
        'Réunion', 'Rumänien', 'Rwanda', 'Ryssland', 'Saint Kitts och Nevis',
        'Saint Lucia', 'Saint-Pierre och Miquelon',
        'Saint Vincent och Grenadinerna', 'Salomonöarna', 'Samoa',
        'Sankta Helena', 'San Marino', 'São Tomé och Príncipe',
        'Saudiarabien', 'Schweiz', 'Senegal', 'Serbien', 'Seychellerna',
        'SierraLeone', 'Singapore', 'Sint Maarten', 'Slovakien', 'Slovenien',
        'Somalia', 'Spanien', 'Sri Lanka', 'Storbritannien', 'Sudan',
        'Surinam', 'Sverige', 'Swaziland', 'Sydafrika', 'Sydkorea', 'Sydsudan',
        'Syrien', 'Tadzjikistan', 'Taiwan', 'Tanzania', 'Tchad', 'Thailand',
        'Tjeckien', 'Togo', 'Tokelauöarna', 'Tonga', 'Trinidad och Tobago',
        'Tunisien', 'Turkiet', 'Turkmenistan', 'Turks-och Caicosöarna',
        'Tuvalu', 'Tyskland', 'Uganda', 'Ukraina', 'Ungern', 'Uruguay', 'USA',
        'Uzbekistan', 'Vanuatu', 'Vatikanstaten', 'Venezuela', 'Vietnam',
        'Vitryssland', 'Wake', 'Wallis-och Futunaöarna', 'Zambia', 'Zimbabwe',
        'Österrike', 'Östtimor'
    )

    states = (
        'Stockholms län', 'Uppsala län', 'Södermanlands län'
        'Östergötlands län', 'Jönköpings län', 'Kronobergs län', 'Kalmar län',
        'Gotlands län', 'Blekinge län', 'Skåne län', 'Hallands län',
        'Västra Götalands län', 'Värmlands län', 'Örebro län',
        'Västmanlands län', 'Dalarnas län', 'Gävleborgs län',
        'Västernorrlands län', 'Jämtlands län', 'Västerbottens län',
        'Norrbottens län'
    )

    def street_prefix(self):
        return self.random_element(self.street_prefixes)

    def city_name(self):
        return self.random_element(self.cities)

    def state(self):
        return self.random_element(self.states)
